@@ -20,7 +20,7 @@ package MongoDB::Database;
 # ABSTRACT: A MongoDB Database
 
 use version;
-our $VERSION = 'v1.3.0'; # TRIAL
+our $VERSION = 'v1.3.1'; # TRIAL
 
 use MongoDB::CommandResult;
 use MongoDB::Error;
@@ -265,10 +265,11 @@ sub get_collection {
 
 { no warnings 'once'; *coll = \&get_collection }
 
-#pod =method get_gridfsbucket
+#pod =method get_gridfsbucket, gfs
 #pod
 #pod     my $grid = $database->get_gridfsbucket;
 #pod     my $grid = $database->get_gridfsbucket($options);
+#pod     my $grid = $database->gfs($options);
 #pod
 #pod This method returns a L<MongoDB::GridFSBucket> object for storing and
 #pod retrieving files from the database.
@@ -278,6 +279,8 @@ sub get_collection {
 #pod
 #pod See L<MongoDB::GridFSBucket> for more information.
 #pod
+#pod The C<gfs> method is an alias for C<get_gridfsbucket>.
+#pod
 #pod =cut
 
 sub get_gridfsbucket {
@@ -295,6 +298,8 @@ sub get_gridfsbucket {
     )
 }
 
+{ no warnings 'once'; *gfs = \&get_gridfsbucket }
+
 #pod =method get_gridfs (DEPRECATED)
 #pod
 #pod     my $grid = $database->get_gridfs;
@@ -303,7 +308,7 @@ sub get_gridfsbucket {
 #pod
 #pod The L<MongoDB::GridFS> class has been deprecated in favor of the new MongoDB
 #pod driver-wide standard GridFS API, available via L<MongoDB::GridFSBucket> and
-#pod the C<get_gridfsbucket> method.
+#pod the C<get_gridfsbucket>/C<gfs> methods.
 #pod
 #pod This method returns a L<MongoDB::GridFS> for storing and retrieving files
 #pod from the database.  Default prefix is "fs", making C<$grid-E<gt>files>
@@ -442,7 +447,7 @@ MongoDB::Database - A MongoDB Database
 
 =head1 VERSION
 
-version v1.3.0
+version v1.3.1
 
 =head1 SYNOPSIS
 
@@ -597,10 +602,11 @@ L<MongoDB::Collection> constructor.
 
 The C<coll> method is an alias for C<get_collection>.
 
-=head2 get_gridfsbucket
+=head2 get_gridfsbucket, gfs
 
     my $grid = $database->get_gridfsbucket;
     my $grid = $database->get_gridfsbucket($options);
+    my $grid = $database->gfs($options);
 
 This method returns a L<MongoDB::GridFSBucket> object for storing and
 retrieving files from the database.
@@ -610,6 +616,8 @@ L<MongoDB::GridFSBucket> constructor.
 
 See L<MongoDB::GridFSBucket> for more information.
 
+The C<gfs> method is an alias for C<get_gridfsbucket>.
+
 =head2 get_gridfs (DEPRECATED)
 
     my $grid = $database->get_gridfs;
@@ -618,7 +626,7 @@ See L<MongoDB::GridFSBucket> for more information.
 
 The L<MongoDB::GridFS> class has been deprecated in favor of the new MongoDB
 driver-wide standard GridFS API, available via L<MongoDB::GridFSBucket> and
-the C<get_gridfsbucket> method.
+the C<get_gridfsbucket>/C<gfs> methods.
 
 This method returns a L<MongoDB::GridFS> for storing and retrieving files
 from the database.  Default prefix is "fs", making C<$grid-E<gt>files>
