@@ -18,7 +18,7 @@ package MongoDB::GridFSBucket;
 # ABSTRACT: A file storage abstraction
 
 use version;
-our $VERSION = 'v1.3.0'; # TRIAL
+our $VERSION = 'v1.3.1'; # TRIAL
 
 use Moo;
 use MongoDB::GridFSBucket::DownloadStream;
@@ -221,7 +221,6 @@ sub _ensure_indexes {
 #pod
 #pod     $file_doc = $result->next;
 #pod
-#pod
 #pod Executes a query on the file documents collection with a
 #pod L<filter expression|MongoDB::Collection/Filter expression> and
 #pod returns a L<MongoDB::QueryResult> object.  It takes an optional hashref
@@ -234,6 +233,45 @@ sub find {
     return $self->_files->find( $filter, $options )->result;
 }
 
+#pod =method find_one
+#pod
+#pod     $file_doc = $bucket->find_one($filter, $projection);
+#pod     $file_doc = $bucket->find_one($filter, $projection, $options);
+#pod
+#pod Executes a query on the file documents collection with a
+#pod L<filter expression|MongoDB::Collection/Filter expression> and
+#pod returns the first document found, or C<undef> if no document is found.
+#pod
+#pod See L<MongoDB::Collection/find_one> for details about the
+#pod C<$projection> and optional C<$options> fields.
+#pod
+#pod =cut
+
+sub find_one {
+    my ( $self, $filter, $projection, $options ) = @_;
+    return $self->_files->find_one( $filter, $projection, $options );
+}
+
+#pod =method find_id
+#pod
+#pod     $file_doc = $bucket->find_id( $id );
+#pod     $file_doc = $bucket->find_id( $id, $projection );
+#pod     $file_doc = $bucket->find_id( $id, $projection, $options );
+#pod
+#pod Executes a query with a L<filter expression|/Filter expression> of
+#pod C<< { _id => $id } >> and returns a single document or C<undef> if no document
+#pod is found.
+#pod
+#pod See L<MongoDB::Collection/find_one> for details about the
+#pod C<$projection> and optional C<$options> fields.
+#pod
+#pod =cut
+
+sub find_id {
+    my ( $self, $id, $projection, $options ) = @_;
+    return $self->_files->find_id( $id, $projection, $options );
+}
+
 #pod =method open_download_stream
 #pod
 #pod     $stream = $bucket->open_download_stream($id);
@@ -301,7 +339,7 @@ sub open_upload_stream {
             chunk_size_bytes => $self->chunk_size_bytes,
             ( $options ? %$options : () ),
             _bucket  => $self,
-            filename => $filename,
+            filename => "$filename", # stringify path objects
         }
     );
 }
@@ -420,11 +458,11 @@ MongoDB::GridFSBucket - A file storage abstraction
 
 =head1 VERSION
 
-version v1.3.0
+version v1.3.1
 
 =head1 SYNOPSIS
 
-    $bucket = $database->get_gridfsbucket;
+    $bucket = $database->gfs;
 
     # upload a file
     $stream  = $bucket->open_upload_stream("foo.txt");
@@ -443,7 +481,8 @@ This class models a GridFS file store in a MongoDB database and provides an
 API for interacting with it.
 
 Generally, you never construct one of these directly with C<new>.  Instead,
-you call C<get_gridfsbucket> on a L<MongoDB::Database> object.
+you call C<gfs> (short for C<get_gridfsbucket>) on a L<MongoDB::Database>
+object.
 
 =head1 USAGE
 
@@ -595,6 +634,31 @@ L<filter expression|MongoDB::Collection/Filter expression> and
 returns a L<MongoDB::QueryResult> object.  It takes an optional hashref
 of options identical to L<MongoDB::Collection/find>.
 
+=head2 find_one
+
+    $file_doc = $bucket->find_one($filter, $projection);
+    $file_doc = $bucket->find_one($filter, $projection, $options);
+
+Executes a query on the file documents collection with a
+L<filter expression|MongoDB::Collection/Filter expression> and
+returns the first document found, or C<undef> if no document is found.
+
+See L<MongoDB::Collection/find_one> for details about the
+C<$projection> and optional C<$options> fields.
+
+=head2 find_id
+
+    $file_doc = $bucket->find_id( $id );
+    $file_doc = $bucket->find_id( $id, $projection );
+    $file_doc = $bucket->find_id( $id, $projection, $options );
+
+Executes a query with a L<filter expression|/Filter expression> of
+C<< { _id => $id } >> and returns a single document or C<undef> if no document
+is found.
+
+See L<MongoDB::Collection/find_one> for details about the
+C<$projection> and optional C<$options> fields.
+
 =head2 open_download_stream
 
     $stream = $bucket->open_download_stream($id);
