@@ -18,7 +18,7 @@ package MongoDB::GridFSBucket::UploadStream;
 # ABSTRACT: File handle abstraction for uploading
 
 use version;
-our $VERSION = 'v1.3.0'; # TRIAL
+our $VERSION = 'v1.3.1'; # TRIAL
 
 use Moo;
 use Encode;
@@ -273,12 +273,14 @@ sub abort {
 
 #pod =method close
 #pod
-#pod     $stream->close;
+#pod     $file_doc = $stream->close;
 #pod
 #pod Closes the stream and flushes any remaining data to the database. Once this is
 #pod done a file document is created in the GridFS bucket, making the uploaded file
 #pod visible in subsequent queries or downloads.
 #pod
+#pod On success, the file document hash reference is returned as a convenience.
+#pod
 #pod B<Important notes:>
 #pod
 #pod =for :list
@@ -313,7 +315,7 @@ sub close {
         MongoDB::GridFSError->throw("Error inserting file document: $@");
     }
     $self->_set__closed(1);
-    return 1;
+    return $filedoc;
 }
 
 #pod =method fileno
@@ -400,6 +402,15 @@ sub TIEHANDLE {
     return $self;
 }
 
+sub BINMODE {
+    my ( $self, $mode ) = @_;
+    if ( !$mode || $mode eq ':raw' ) {
+        return 1;
+    }
+    $! = "binmode for " . __PACKAGE__ . " only supports :raw mode.";
+    return
+}
+
 {
     no warnings 'once';
     *PRINT  = \&print;
@@ -410,7 +421,6 @@ sub TIEHANDLE {
 }
 
 my @unimplemented = qw(
-  BINMODE
   EOF
   GETC
   READ
@@ -441,7 +451,7 @@ MongoDB::GridFSBucket::UploadStream - File handle abstraction for uploading
 
 =head1 VERSION
 
-version v1.3.0
+version v1.3.1
 
 =head1 SYNOPSIS
 
@@ -547,12 +557,14 @@ and closing the stream.
 
 =head2 close
 
-    $stream->close;
+    $file_doc = $stream->close;
 
 Closes the stream and flushes any remaining data to the database. Once this is
 done a file document is created in the GridFS bucket, making the uploaded file
 visible in subsequent queries or downloads.
 
+On success, the file document hash reference is returned as a convenience.
+
 B<Important notes:>
 
 =over 4
